==> freecad_0.21.2+dfsg1.orig.tar.xz: FreeCAD-0.21.2/src/Mod/Points/Gui/Resources/translations/Points_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl" sourcelanguage="en">
  <context>
    <name>CmdPointsConvert</name>
    <message>
      <location filename="../../Command.cpp" line="189"/>
      <source>Points</source>
      <translation>Punkty</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="190"/>
      <source>Convert to points...</source>
      <translation>Konwertuj na punkty ...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="191"/>
      <location filename="../../Command.cpp" line="193"/>
      <source>Convert to points</source>
      <translation>Konwertuj na punkty</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsExport</name>
    <message>
      <location filename="../../Command.cpp" line="112"/>
      <source>Points</source>
      <translation>Punkty</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="113"/>
      <source>Export points...</source>
      <translation>Eksport punktów ...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="114"/>
      <location filename="../../Command.cpp" line="116"/>
      <source>Exports a point cloud</source>
      <translation>Eksportuje chmurę punktów</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsImport</name>
    <message>
      <location filename="../../Command.cpp" line="67"/>
      <source>Points</source>
      <translation>Punkty</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="68"/>
      <source>Import points...</source>
      <translation>Import punktów ...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="69"/>
      <location filename="../../Command.cpp" line="71"/>
      <source>Imports a point cloud</source>
      <translation>Importuje chmurę punktów</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsMerge</name>
    <message>
      <location filename="../../Command.cpp" line="310"/>
      <source>Points</source>
      <translation>Punkty</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="311"/>
      <source>Merge point clouds</source>
      <translation>Scal chmury punktów</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="312"/>
      <location filename="../../Command.cpp" line="314"/>
      <source>Merge several point clouds into one</source>
      <translation>Scal kilka chmur punktów w jedną</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsPolyCut</name>
    <message>
      <location filename="../../Command.cpp" line="265"/>
      <source>Points</source>
      <translation>Punkty</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="266"/>
      <source>Cut point cloud</source>
      <translation>Wytnij punkt chmury</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="267"/>
      <location filename="../../Command.cpp" line="269"/>
      <source>Cuts a point cloud with a picked polygon</source>
      <translation>Tnie chmurę punktów za pomocą wskazanego wielokąta</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsStructure</name>
    <message>
      <location filename="../../Command.cpp" line="371"/>
      <source>Points</source>
      <translation>Punkty</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="372"/>
      <source>Structured point cloud</source>
      <translation>Uporządkowana chmura punktów</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="373"/>
      <location filename="../../Command.cpp" line="375"/>
      <source>Convert points to structured point cloud</source>
      <translation>Konwertuj punkty do uporządkowanej chmury punktów</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsTransform</name>
    <message>
      <location filename="../../Command.cpp" line="152"/>
      <source>Points</source>
      <translation>Punkty</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="153"/>
      <source>Transform Points</source>
      <translation>Przekształć Punkty</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="154"/>
      <location filename="../../Command.cpp" line="156"/>
      <source>Test to transform a point cloud</source>
      <translation>Test przekształcenia chmury punktów</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <location filename="../../Command.cpp" line="88"/>
      <source>Import points</source>
      <translation>Importuj punkty</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="168"/>
      <source>Transform points</source>
      <translation>Przekształć punkty</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="214"/>
      <source>Convert to points</source>
      <translation>Konwertuj na punkty</translation>
    </message>
    <message>
      <location filename="../../ViewProvider.cpp" line="456"/>
      <location filename="../../ViewProvider.cpp" line="615"/>
      <source>Cut points</source>
      <translation>Wytnij punkty</translation>
    </message>
  </context>
  <context>
    <name>PointsGui::DlgPointsRead</name>
    <message>
      <location filename="../../DlgPointsRead.ui" line="14"/>
      <source>ASCII points import</source>
      <translation>Import punktów ASCII</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="34"/>
      <source>Template:</source>
      <translation>Szablon:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="46"/>
      <source>Special lines</source>
      <translation>Wiersze specjalne</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="58"/>
      <source>First line:</source>
      <translation>Pierwszy wiersz:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="70"/>
      <source>Ignore</source>
      <translation>Ignoruj</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="80"/>
      <source>Number of points</source>
      <translation>Liczba punktów</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="101"/>
      <source>Cluster by lines starting with:</source>
      <translation>Grupuj według wierszy zaczynających się od:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="111"/>
      <source>Ignore lines starting with:</source>
      <translation>Ignoruj ​​linie zaczynające się od:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="126"/>
      <source>Point format</source>
      <translation>Format punktu</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="146"/>
      <source>Number separator:</source>
      <translation>Separator dziesiętny:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="167"/>
      <source>\t</source>
      <translation>\t</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="172"/>
      <source>\w</source>
      <translation>\w</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="180"/>
      <source>Points format:</source>
      <translation>Format punktów:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="188"/>
      <source>X,Y,Z</source>
      <translation>X, Y, Z</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="193"/>
      <source>X,Y</source>
      <translation>X, Y</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="201"/>
      <location filename="../../DlgPointsRead.ui" line="237"/>
      <location filename="../../DlgPointsRead.ui" line="273"/>
      <source>Next block:</source>
      <translation>Następny blok:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="209"/>
      <location filename="../../DlgPointsRead.ui" line="245"/>
      <location filename="../../DlgPointsRead.ui" line="281"/>
      <source>none</source>
      <translation>brak</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="214"/>
      <location filename="../../DlgPointsRead.ui" line="250"/>
      <location filename="../../DlgPointsRead.ui" line="286"/>
      <source>I,J,K (normal vector)</source>
      <translation>I, J, K (wektor normalny)</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="219"/>
      <location filename="../../DlgPointsRead.ui" line="255"/>
      <location filename="../../DlgPointsRead.ui" line="291"/>
      <source>I,K (normal vector 2D)</source>
      <translation>I,K (wektor normalny 2D)</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="224"/>
      <location filename="../../DlgPointsRead.ui" line="260"/>
      <location filename="../../DlgPointsRead.ui" line="296"/>
      <source>R,G,B (color)</source>
      <translation>R, G, B (kolor)</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="229"/>
      <location filename="../../DlgPointsRead.ui" line="265"/>
      <location filename="../../DlgPointsRead.ui" line="301"/>
      <source>I (Gray value)</source>
      <translation>I (wartość w skali szarości)</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="314"/>
      <source>Preview</source>
      <translation>Podgląd</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="341"/>
      <source>Number of previewed lines:</source>
      <translation>Liczba przeglądanych wierszy:</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Command.cpp" line="81"/>
      <location filename="../../Command.cpp" line="129"/>
      <source>Point formats</source>
      <translation>Formaty punktu</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="81"/>
      <location filename="../../Command.cpp" line="129"/>
      <source>All Files</source>
      <translation>Wszystkie pliki</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="208"/>
      <source>Distance</source>
      <translation>Odległość</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="209"/>
      <source>Enter maximum distance:</source>
      <translation>Największa odległość:</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="34"/>
      <source>Points tools</source>
      <translation>Narzędzia do punktów</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="35"/>
      <source>&amp;Points</source>
      <translation>&amp;Punkty</translation>
    </message>
  </context>
</TS>

==> freecad_1.0.0+dfsg.orig.tar.xz: FreeCAD-1.0.0/src/Mod/Points/Gui/Resources/translations/Points_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl" sourcelanguage="en">
  <context>
    <name>CmdPointsConvert</name>
    <message>
      <location filename="../../Command.cpp" line="206"/>
      <source>Points</source>
      <translation>Punkty</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="207"/>
      <source>Convert to points...</source>
      <translation>Konwertuj na punkty ...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="208"/>
      <location filename="../../Command.cpp" line="210"/>
      <source>Convert to points</source>
      <translation>Konwertuj na punkty</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsExport</name>
    <message>
      <location filename="../../Command.cpp" line="120"/>
      <source>Points</source>
      <translation>Tylko punkty</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="121"/>
      <source>Export points...</source>
      <translation>Eksport punktów ...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="122"/>
      <location filename="../../Command.cpp" line="124"/>
      <source>Exports a point cloud</source>
      <translation>Eksportuje chmurę punktów</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsImport</name>
    <message>
      <location filename="../../Command.cpp" line="67"/>
      <source>Points</source>
      <translation>Punkty</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="68"/>
      <source>Import points...</source>
      <translation>Import punktów ...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="69"/>
      <location filename="../../Command.cpp" line="71"/>
      <source>Imports a point cloud</source>
      <translation>Importuje chmurę punktów</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsMerge</name>
    <message>
      <location filename="../../Command.cpp" line="342"/>
      <source>Points</source>
      <translation>Tylko punkty</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="343"/>
      <source>Merge point clouds</source>
      <translation>Scal chmury punktów</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="344"/>
      <location filename="../../Command.cpp" line="346"/>
      <source>Merge several point clouds into one</source>
      <translation>Scal kilka chmur punktów w jedną</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsPolyCut</name>
    <message>
      <location filename="../../Command.cpp" line="294"/>
      <source>Points</source>
      <translation>Tylko punkty</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="295"/>
      <source>Cut point cloud</source>
      <translation>Wytnij punkt chmury</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="296"/>
      <location filename="../../Command.cpp" line="298"/>
      <source>Cuts a point cloud with a picked polygon</source>
      <translation>Tnie chmurę punktów za pomocą wskazanego wielokąta</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsStructure</name>
    <message>
      <location filename="../../Command.cpp" line="405"/>
      <source>Points</source>
      <translation>Punkty</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="406"/>
      <source>Structured point cloud</source>
      <translation>Uporządkowana chmura punktów</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="407"/>
      <location filename="../../Command.cpp" line="409"/>
      <source>Convert points to structured point cloud</source>
      <translation>Konwertuj punkty do uporządkowanej chmury punktów</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsTransform</name>
    <message>
      <location filename="../../Command.cpp" line="167"/>
      <source>Points</source>
      <translation>Punkty</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="168"/>
      <source>Transform Points</source>
      <translation>Przekształć Punkty</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="169"/>
      <location filename="../../Command.cpp" line="171"/>
      <source>Test to transform a point cloud</source>
      <translation>Test przekształcenia chmury punktów</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <location filename="../../Command.cpp" line="92"/>
      <source>Import points</source>
      <translation>Importuj punkty</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="183"/>
      <source>Transform points</source>
      <translation>Przekształć punkty</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="240"/>
      <source>Convert to points</source>
      <translation>Konwertuj na punkty</translation>
    </message>
    <message>
      <location filename="../../ViewProvider.cpp" line="485"/>
      <location filename="../../ViewProvider.cpp" line="653"/>
      <source>Cut points</source>
      <translation>Wytnij punkty</translation>
    </message>
  </context>
  <context>
    <name>PointsGui::DlgPointsRead</name>
    <message>
      <location filename="../../DlgPointsRead.ui" line="14"/>
      <source>ASCII points import</source>
      <translation>Import punktów ASCII</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="34"/>
      <source>Template:</source>
      <translation>Szablon:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="46"/>
      <source>Special lines</source>
      <translation>Wiersze specjalne</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="58"/>
      <source>First line:</source>
      <translation>Pierwszy wiersz:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="70"/>
      <source>Ignore</source>
      <translation>Ignoruj</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="80"/>
      <source>Number of points</source>
      <translation>Liczba punktów</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="101"/>
      <source>Cluster by lines starting with:</source>
      <translation>Grupuj według wierszy zaczynających się od:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="111"/>
      <source>Ignore lines starting with:</source>
      <translation>Ignoruj ​​linie zaczynające się od:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="126"/>
      <source>Point format</source>
      <translation>Format punktu</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="146"/>
      <source>Number separator:</source>
      <translation>Separator dziesiętny:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="167"/>
      <source>\t</source>
      <translation>\t</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="172"/>
      <source>\w</source>
      <translation>\w</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="180"/>
      <source>Points format:</source>
      <translation>Format punktów:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="188"/>
      <source>X,Y,Z</source>
      <translation>X, Y, Z</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="193"/>
      <source>X,Y</source>
      <translation>X, Y</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="201"/>
      <location filename="../../DlgPointsRead.ui" line="237"/>
      <location filename="../../DlgPointsRead.ui" line="273"/>
      <source>Next block:</source>
      <translation>Następny blok:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="209"/>
      <location filename="../../DlgPointsRead.ui" line="245"/>
      <location filename="../../DlgPointsRead.ui" line="281"/>
      <source>none</source>
      <translation>brak</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="214"/>
      <location filename="../../DlgPointsRead.ui" line="250"/>
      <location filename="../../DlgPointsRead.ui" line="286"/>
      <source>I,J,K (normal vector)</source>
      <translation>I, J, K (wektor normalny)</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="219"/>
      <location filename="../../DlgPointsRead.ui" line="255"/>
      <location filename="../../DlgPointsRead.ui" line="291"/>
      <source>I,K (normal vector 2D)</source>
      <translation>I,K (wektor normalny 2D)</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="224"/>
      <location filename="../../DlgPointsRead.ui" line="260"/>
      <location filename="../../DlgPointsRead.ui" line="296"/>
      <source>R,G,B (color)</source>
      <translation>R, G, B (kolor)</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="229"/>
      <location filename="../../DlgPointsRead.ui" line="265"/>
      <location filename="../../DlgPointsRead.ui" line="301"/>
      <source>I (Gray value)</source>
      <translation>I (wartość w skali szarości)</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="314"/>
      <source>Preview</source>
      <translation>Podgląd</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="341"/>
      <source>Number of previewed lines:</source>
      <translation>Liczba przeglądanych wierszy:</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Command.cpp" line="84"/>
      <location filename="../../Command.cpp" line="141"/>
      <source>Point formats</source>
      <translation>Formaty punktu</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="84"/>
      <location filename="../../Command.cpp" line="141"/>
      <source>All Files</source>
      <translation>Wszystkie pliki</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="227"/>
      <source>Distance</source>
      <translation>Odległość</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="228"/>
      <source>Enter maximum distance:</source>
      <translation>Największa odległość:</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="34"/>
      <source>Points tools</source>
      <translation>Narzędzia do punktów</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="35"/>
      <source>&amp;Points</source>
      <translation>&amp;Punkty</translation>
    </message>
  </context>
</TS>
